calculate_FIM: Calculation of Fisher Information Matrix
Description
The sensitivities at the different times are calculated by
linear interpolation of the results provided in sensitivities.
Usage
calculate_FIM(sensitivities, times)
Arguments
times
Numeric vector of time points where observations will be taken.
Value
Matrix with the estimation of the Fisher Information Matrix.