Calculation of the detection limit depending on the model.
calculate_limit(model, pars, limit, temp_range)character string defining the inactivation model to use.
list defining the model parameters according to the rules defined in the bioinactivation package.
numerical value describing the maximum number of log-reductions that can be identified in the experiment limit = logDL - logN0, where DL is the detection limit.
Numeric vector that defines the range of possible temperatures
Numerical value that indicates the limit of detection