Points outside of the allowable area are moved back in time to the detection limit
criterium_Emod_iso(x, model, pars, limit)a numeric vector of length n defining the design matrix.
The first n/2 elements are the time points and the last n/2 are the
temperatures of these points.
character string defining the inactivation model to use.
list defining the model parameters according to the rules defined in the bioinactivation package.
numerical value describing the maximum number of log-reductions that can be identified in the experiment limit = logDL - logN0, where DL is the detection limit.
Numeric value of the objective function for criterium E modified, which is a determinant of the FIM.