Learn R Programming

bioOED (version 0.2.1)

detection_bigelow: Detection limit of the Bigelow model

Description

Calculation of the detection limit for the Bigelow model

Usage

detection_bigelow(pars, temperature, limit)

Arguments

pars

list defining the model parameters according to the rules defined in the bioinactivation package.

temperature

numerical value that describes the temperature at which the detection limit will be calculated

limit

numerical value describing the maximum number of log-reductions that can be identified in the experiment limit = logDL - logN0, where DL is the detection limit.

Value

Numerical value that indicates the limit of detection for that temperature for the Bigelow model

Examples

Run this code
# NOT RUN {
 
pars <- list(temp_ref = 55,
        z = 5.18 ,
        D_R = 12.10 )
detection_bigelow( pars, temperature = 57, limit=7)
# }

Run the code above in your browser using DataLab