detection_mafart: Detection limit of the Mafart model
Description
Calculation of the detection limit for the Mafart model
Usage
detection_mafart(pars, temperature, limit)
Arguments
pars
list defining the model parameters according to the rules defined in the bioinactivation package.
temperature
numerical value that describes the temperature at which the detection limit will be calculated
limit
numerical value describing the maximum number of log-reductions
that can be identified in the experiment limit = logDL - logN0, where DL
is the detection limit.
Value
Numerical value that indicates the limit of detection for that temperature for the Mafart model