Learn R Programming

bioOED (version 0.2.1)

get_isothermal_correlation: Parameter correlation for isothermal inactivation experiments

Description

Parameter correlation for isothermal inactivation experiments

Usage

get_isothermal_correlation(model, exp_design, pars)

Arguments

model

character defining the inactivation model according to the rules in the bioinactivation package.

exp_design

data.frame with two columns named times and temperature describing the experiment design.

pars

list defining the model parameters according to the rules defined in the bioinactivation package.

Examples

Run this code
# NOT RUN {
library(tidyverse)
time_profile <- seq(0, 50, length = 20)
Temp_profile <- seq(52.5,60, length = 3)

exp_design <- expand.grid(time_profile,Temp_profile) %>%
  rename(times = Var1, temperature = Var2)

pars <- list(temp_crit = 55,
             n = 1.5,
             k_b = 0.1)

get_isothermal_correlation("Peleg", exp_design, pars )

# }

Run the code above in your browser using DataLab