Learn R Programming

bioOED (version 0.2.1)

inactivation_sens_handler: Handler for the calculation of sensitivities of inactivation models

Description

Handler for the calculation of sensitivities of inactivation models

Usage

inactivation_sens_handler(model_parms, inactivation_model, times,
  temp_profile, parms_fix)

Arguments

model_parms

A named vector or list with the values of the model parameters. See the documentation of bioinactivation::predict_inactivation.

inactivation_model

A character defining the inactivation model to use. See the documentation of bioinactivation::predict_inactivation.

times

A numeric vector describing the points where the solution will be calculated. See the documentation of bioinactivation::predict_inactivation.

temp_profile

A data frame describing the temperature profile. See the documentation of bioinactivation::predict_inactivation.

parms_fix

A named vector or list with the values of the known model parameters. See the documentation of bioinactivation::predict_inactivation.