Local sensitivities of the Bigelow model
sensitivities_Bigelow(exp_design, pars)data.frame with two columns named times and
temperature describing the experiment design.
list defining the model parameters according to the rules defined
in the bioinactivation package.
A data frame with the same number of rows as exp_design with
additional column for local sensitivities. These are named D_R and z for local
sensitivities and D_R_scaled and z_scaled for scaled locan sensitivities.