Learn R Programming

bioOED (version 0.2.1)

sensitivities_Peleg: Local sensitivities of the Peleg model

Description

Local sensitivities of the Peleg model

Usage

sensitivities_Peleg(exp_design, pars)

Arguments

exp_design

data.frame with two columns named times and temperature describing the experiment design.

pars

list defining the model parameters according to the rules defined in the bioinactivation package.