Handler for the calculation of sensitivities of inactivation models
inactivation_sens_handler(model_parms, inactivation_model, times,
temp_profile, parms_fix)A named vector or list with the values of the model parameters. See the documentation of bioinactivation::predict_inactivation.
A character defining the inactivation model to use. See the documentation of bioinactivation::predict_inactivation.
A numeric vector describing the points where the solution will be calculated. See the documentation of bioinactivation::predict_inactivation.
A data frame describing the temperature profile. See the documentation of bioinactivation::predict_inactivation.
A named vector or list with the values of the known model parameters. See the documentation of bioinactivation::predict_inactivation.